@@ -11,6 +11,12 @@ from plone.app.querystring import queryparser
 from collective.media.interfaces import ICanContainMedia
 import re
 
+try:
+    from Products.PloneGetPaid.interfaces import IBuyableMarker
+    GETPAID_EXISTS = True
+except ImportError:
+    GETPAID_EXISTS = False
+
 
 class CommonBrowserView(BrowserView):
     """
@@ -111,6 +117,12 @@ class CommonBrowserView(BrowserView):
         else:
             return person
             
+    def isBuyable(self, item):
+        if not GETPAID_EXISTS:
+            return False
+        else:
+            return IBuyableMarker.providedBy(item)
+            
     def _uniq(self, alist):    # Fastest order preserving
         set = {}
         return [set.setdefault(e,e) for e in alist if e not in set]
